@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Ported Perl from the book's C code
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -12,6 +12,7 @@ use Carp qw(croak);
 use Data::Munge qw(list2re);
 use Integer::Partition ();
 use List::Util qw(all any);
+use Math::NumSeq::SqrtContinued ();
 use Math::Sequence::DeBruijn qw(debruijn);
 use Music::AtonalUtil ();
 use namespace::clean;
@@ -25,6 +26,42 @@ has verbose => (
 
 
 
+sub cfcv {
+    my ($self, @terms) = @_;
+
+    my $p0 = 0;
+    my $p1 = 1;
+    my $p2;
+    my $q0 = 1;
+    my $q1 = 0;
+    my $q2;
+
+    for my $t (@terms) {
+      $p2 = $t * $p1 + $p0;
+      $q2 = $t * $q1 + $q0;
+      $p0 = $p1;
+      $p1 = $p2;
+      $q0 = $q1;
+      $q1 = $q2;
+    }
+
+    return [ $p2, $q2 ];
+}
+
+
+sub cfsqrt {
+    my ($self, $n, $m) = @_;
+    $m ||= $n;
+    my @terms;
+    my $seq = Math::NumSeq::SqrtContinued->new(sqrt => $n);
+    for my $i (1 .. $m) {
+        my ($j, $value) = $seq->next;
+        push @terms, $value;
+    }
+    return \@terms;
+}
+
+
 sub chsequl {
     my ($self, $t, $p, $q, $n) = @_;
     die "Usage: chsequl(\$type, \$numerator, \$denominator [\$terms])\n"
@@ -392,7 +429,7 @@ sub partm {
 }
 
 
-sub permute {
+sub permi {
     my ($self, $parts) = @_;
     my @permutations = permutations($parts);
     return \@permutations;
@@ -434,7 +471,7 @@ Music::CreatingRhythms - Ported Perl from the book's C code
 
 =head1 VERSION
 
-version 0.0101
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -466,18 +503,29 @@ Show progress. * This is not showing anything yet, however.
 
 =head2 new
 
-  $mcr = Music::CreatingRhythms->new(verbose => 1);
+  $mcr = Music::CreatingRhythms->new;
 
 Create a new C<Music::CreatingRhythms> object.
 
-=for Pod::Coverage BUILD
+=head2 cfcv
+
+  $convergent = $mcr->cfcv(@terms);
+
+Calculate a continued fraction convergent given the B<terms>.
+
+=head2 cfsqrt
+
+  $terms = $mcr->cfsqrt($n, $m);
+
+Calculate the continued fraction for C<sqrt(n)> to B<m> digits, where
+B<n> and B<m> are integers.
 
 =head2 chsequl
 
   $sequence = $mcr->chsequl($t, $p, $q);
   $sequence = $mcr->chsequl($t, $p, $q, $n);
 
-Generate the upper or lower Christoffel word for p/q
+Generate the upper or lower Christoffel word for B<p> and B<q>.
 
 Arguments:
 
@@ -583,9 +631,9 @@ B<p1, p2, ... pn>.
 
 Generate all partitions of B<n> into B<m> parts.
 
-=head2 permute
+=head2 permi
 
-  $all_permutations = $mcr->permute(\@parts);
+  $all_permutations = $mcr->permi(\@parts);
 
 Return all permutations of the given B<parts> list as an
 array-reference of array-references.
@@ -609,7 +657,7 @@ Rotate a necklace of the given B<parts>, B<n> times.
 
 L<https://abrazol.com/books/rhythm1/> "Creating Rhythms"
 
-The F<t/01-methods.t> program included with this distribution.
+The F<t/01-methods.t> and F<eg/*> programs included with this distribution.
 
 L<Algorithm::Combinatorics>
 
